==> v0.7.tar.gz: qqsp/Qqsp.ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="59"/>
        <source>ToolBar</source>
        <translation>Панель инструментов</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="284"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="474"/>
        <source>&amp;Quest</source>
        <translation>&amp;Квест</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="477"/>
        <source>Open game...</source>
        <translation>Открыть игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="482"/>
        <source>Restart game</source>
        <translation>Перезагрузить игру</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="490"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="496"/>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="499"/>
        <source>Open saved game...</source>
        <translation>Открыть сохраненную игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="503"/>
        <source>Save game...</source>
        <translation>Сохранить игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="507"/>
        <source>Quick Load</source>
        <translation>Быстрая загрузка</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="511"/>
        <source>Quick Save</source>
        <translation>Быстрое сохранение</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="517"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="520"/>
        <source>Show / Hide</source>
        <translation>Показать / Скрыть</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="550"/>
        <source>Captions</source>
        <translation>Заголовки</translation>
    </message>
    <message>
        <source>Sound volume...</source>
        <translation type="vanished">Громкость...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="580"/>
        <source>Window / Fullscreen mode</source>
        <translation>Оконный / Полноэкранный режим</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="588"/>
        <source>Display HTML code as plain text</source>
        <translation>Отображать исходный код HTML</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="599"/>
        <source>Options...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="605"/>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="608"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="623"/>
        <source>Main desc</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="629"/>
        <source>Objects</source>
        <translation>Предметы</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="641"/>
        <source>Actions</source>
        <translation>Действия</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="654"/>
        <source>Additional desc</source>
        <translation>Дополнительное описание</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="667"/>
        <source>Input area</source>
        <translation>Поле ввода</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="868"/>
        <location filename="mainwindow.cpp" line="875"/>
        <source>Select game file</source>
        <translation>Выберите файл игры</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="868"/>
        <location filename="mainwindow.cpp" line="875"/>
        <source>QSP games (*.qsp *.gam)</source>
        <translation>Файлы игры QSP (*.qsp *.gam)</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="262"/>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="317"/>
        <source>Input data</source>
        <translation>Ввод данных</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="351"/>
        <location filename="mainwindow.cpp" line="908"/>
        <source>Select saved game file</source>
        <translation>Выберите файл сохраненной игры</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="351"/>
        <location filename="callbacks_gui.cpp" line="369"/>
        <location filename="mainwindow.cpp" line="908"/>
        <location filename="mainwindow.cpp" line="923"/>
        <source>Saved game files (*.sav)</source>
        <translation>Файлы сохранений (*.sav)</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="369"/>
        <location filename="mainwindow.cpp" line="923"/>
        <source>Select file to save</source>
        <translation>Выберите файл для сохранения</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="980"/>
        <source>, </source>
        <translation>, </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="981"/>
        <source>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2017, S.&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Авторские права &amp;copy; 2017, S.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="983"/>
        <source>&lt;p&gt;Application version: %1&lt;br&gt;QSP library version: %2&lt;br&gt;Application compilation date: %3&lt;br&gt;Library compilation date: %4&lt;/p&gt;</source>
        <translation>&lt;p&gt;Версия приложения: %1&lt;br&gt;Версия библиотеки QSP: %2&lt;br&gt;Дата компиляции приложения: %3&lt;br&gt;Дата компиляции библиотеки: %4&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="984"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="optionsdialog.ui" line="17"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="25"/>
        <source>Use custom font size</source>
        <translation>Использовать выбранный размер шрифта</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="39"/>
        <source>Use custom font</source>
        <translation>Использовать выбранный шрифт</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="68"/>
        <location filename="optionsdialog.ui" line="124"/>
        <location filename="optionsdialog.ui" line="204"/>
        <location filename="optionsdialog.ui" line="253"/>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="77"/>
        <source>Custom background color</source>
        <translation>Использовать выбранный цвет фона</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="133"/>
        <source>Language</source>
        <translation>Язык (Language)</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="143"/>
        <source>Custom text color</source>
        <translation>Использовать выбранный цвет текста</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="150"/>
        <source>Custom link color</source>
        <translation>Использовать выбранный цвет ссылок</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="157"/>
        <source>Autostart last game</source>
        <translation>Автозагрузка последней игры</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="262"/>
        <source>Separate config per game</source>
        <translation>Отдельные настройки для каждой игры</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="269"/>
        <source>Sound volume</source>
        <translation>Громкость звука</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="286"/>
        <source>Disable video</source>
        <translation>Отключить поддержку видео</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="323"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="330"/>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="16"/>
        <source>__LANGNAME__</source>
        <translation>Русский</translation>
    </message>
    <message>
        <location filename="main.cpp" line="17"/>
        <location filename="mainwindow.cpp" line="100"/>
        <source>__LANGID__</source>
        <translation>ru_RU</translation>
    </message>
</context>
<context>
    <name>QspImgCanvas</name>
    <message>
        <location filename="qspimgcanvas.cpp" line="9"/>
        <source>Image</source>
        <translation>Изображение</translation>
    </message>
</context>
<context>
    <name>QspMsgDlg</name>
    <message>
        <location filename="qspmsgdlg.cpp" line="32"/>
        <source>OK</source>
        <translation>Ок</translation>
    </message>
</context>
<context>
    <name>__LANG__</name>
    <message>
        <location filename="optionsdialog.cpp" line="48"/>
        <location filename="optionsdialog.cpp" line="57"/>
        <source>__LANGNAME__</source>
        <translation>Русский</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="48"/>
        <location filename="optionsdialog.cpp" line="57"/>
        <source>__LANGID__</source>
        <translation>ru_RU</translation>
    </message>
</context>
</TS>

==> v1.5.tar.gz: qqsp/Qqsp.ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.cpp" line="66"/>
        <source>ToolBar</source>
        <translation>Панель инструментов</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="327"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="534"/>
        <source>&amp;Quest</source>
        <translation>&amp;Квест</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="537"/>
        <source>Open game...</source>
        <translation>Открыть игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="542"/>
        <source>Restart game</source>
        <translation>Перезагрузить игру</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="550"/>
        <source>Exit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="556"/>
        <source>&amp;Game</source>
        <translation>&amp;Игра</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="559"/>
        <source>Open saved game...</source>
        <translation>Открыть сохраненную игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="563"/>
        <source>Save game...</source>
        <translation>Сохранить игру...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="567"/>
        <source>Quick Load</source>
        <translation>Быстрая загрузка</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="571"/>
        <source>Quick Save</source>
        <translation>Быстрое сохранение</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="577"/>
        <source>&amp;Settings</source>
        <translation>&amp;Настройки</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="580"/>
        <source>Show / Hide</source>
        <translation>Показать / Скрыть</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="610"/>
        <source>Captions</source>
        <translation>Заголовки</translation>
    </message>
    <message>
        <source>Sound volume...</source>
        <translation type="vanished">Громкость...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="640"/>
        <source>Window / Fullscreen mode</source>
        <translation>Оконный / Полноэкранный режим</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="648"/>
        <source>Display HTML code as plain text</source>
        <translation>Отображать исходный код HTML</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="659"/>
        <source>Options...</source>
        <translation>Настройки...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="665"/>
        <source>&amp;Help</source>
        <translation>&amp;Помощь</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="668"/>
        <source>About...</source>
        <translation>О программе...</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="684"/>
        <source>Main desc</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="690"/>
        <source>Objects</source>
        <translation>Предметы</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="702"/>
        <source>Actions</source>
        <translation>Действия</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="715"/>
        <source>Additional desc</source>
        <translation>Дополнительное описание</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="729"/>
        <source>Input area</source>
        <translation>Поле ввода</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="941"/>
        <location filename="mainwindow.cpp" line="948"/>
        <source>Select game file</source>
        <translation>Выберите файл игры</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="941"/>
        <location filename="mainwindow.cpp" line="948"/>
        <source>QSP games (*.qsp *.gam)</source>
        <translation>Файлы игры QSP (*.qsp *.gam)</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="262"/>
        <source>Info</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="317"/>
        <source>Input data</source>
        <translation>Ввод данных</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="351"/>
        <location filename="mainwindow.cpp" line="981"/>
        <source>Select saved game file</source>
        <translation>Выберите файл сохраненной игры</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="351"/>
        <location filename="callbacks_gui.cpp" line="369"/>
        <location filename="mainwindow.cpp" line="981"/>
        <location filename="mainwindow.cpp" line="996"/>
        <source>Saved game files (*.sav)</source>
        <translation>Файлы сохранений (*.sav)</translation>
    </message>
    <message>
        <location filename="callbacks_gui.cpp" line="369"/>
        <location filename="mainwindow.cpp" line="996"/>
        <source>Select file to save</source>
        <translation>Выберите файл для сохранения</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1053"/>
        <source>, </source>
        <translation>, </translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1054"/>
        <source>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Copyright &amp;copy; 2017, S.&lt;/p&gt;</source>
        <translation>&lt;h2&gt;Qqsp&lt;/h2&gt;&lt;p&gt;Авторские права &amp;copy; 2017, S.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1056"/>
        <source>&lt;p&gt;Application version: %1&lt;br&gt;QSP library version: %2&lt;br&gt;Qt library version: %3&lt;br&gt;Application compilation date: %4&lt;br&gt;Library compilation date: %5&lt;/p&gt;</source>
        <oldsource>&lt;p&gt;Application version: %1&lt;br&gt;QSP library version: %2&lt;br&gt;Application compilation date: %3&lt;br&gt;Library compilation date: %4&lt;/p&gt;</oldsource>
        <translation>&lt;p&gt;Версия приложения: %1&lt;br&gt;Версия библиотеки QSP: %2&lt;br&gt;Версия библиотеки Qt: %3&lt;br&gt;Дата компиляции приложения: %4&lt;br&gt;Дата компиляции библиотеки: %5&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="1057"/>
        <source>About</source>
        <translation>О программе</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <location filename="optionsdialog.ui" line="17"/>
        <source>Options</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="25"/>
        <source>Use custom font size</source>
        <translation>Использовать выбранный размер шрифта</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="39"/>
        <source>Use custom font</source>
        <translation>Использовать выбранный шрифт</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="68"/>
        <location filename="optionsdialog.ui" line="124"/>
        <location filename="optionsdialog.ui" line="204"/>
        <location filename="optionsdialog.ui" line="253"/>
        <source>Select</source>
        <translation>Выбрать</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="77"/>
        <source>Custom background color</source>
        <translation>Использовать выбранный цвет фона</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="133"/>
        <source>Language</source>
        <translation>Язык (Language)</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="143"/>
        <source>Custom text color</source>
        <translation>Использовать выбранный цвет текста</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="150"/>
        <source>Custom link color</source>
        <translation>Использовать выбранный цвет ссылок</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="157"/>
        <source>Autostart last game</source>
        <translation>Автозагрузка последней игры</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="262"/>
        <source>Separate config per game</source>
        <translation>Отдельные настройки для каждой игры</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="269"/>
        <source>Sound volume</source>
        <translation>Громкость звука</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="286"/>
        <source>Disable video</source>
        <translation>Отключить поддержку видео</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="293"/>
        <source>Force autoplay and loop for video</source>
        <translation>Добавлять autoplay и loop для &lt;video&gt;</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="330"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="optionsdialog.ui" line="337"/>
        <source>Ok</source>
        <translation>Ок</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="main.cpp" line="18"/>
        <source>__LANGNAME__</source>
        <translation>Русский</translation>
    </message>
    <message>
        <location filename="main.cpp" line="19"/>
        <location filename="mainwindow.cpp" line="108"/>
        <source>__LANGID__</source>
        <translation>ru_RU</translation>
    </message>
</context>
<context>
    <name>QspExecWebEngineUrlSchemeHandler</name>
    <message>
        <location filename="qspexecwebengineurlschemehandler.cpp" line="41"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>QspImgCanvas</name>
    <message>
        <location filename="qspimgcanvas.cpp" line="9"/>
        <source>Image</source>
        <translation>Изображение</translation>
    </message>
</context>
<context>
    <name>QspMsgDlg</name>
    <message>
        <location filename="qspmsgdlg.cpp" line="32"/>
        <source>OK</source>
        <translation>Ок</translation>
    </message>
</context>
<context>
    <name>__LANG__</name>
    <message>
        <location filename="optionsdialog.cpp" line="49"/>
        <location filename="optionsdialog.cpp" line="58"/>
        <source>__LANGNAME__</source>
        <translation>Русский</translation>
    </message>
    <message>
        <location filename="optionsdialog.cpp" line="49"/>
        <location filename="optionsdialog.cpp" line="58"/>
        <source>__LANGID__</source>
        <translation>ru_RU</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="main.cpp" line="32"/>
        <source>Game file to open.</source>
        <translation>Путь до файла игры.</translation>
    </message>
</context>
</TS>
